@@ -1,6 +1,6 @@
 package Bundle::WWW::Search::ALL;
 
-$VERSION = '1.09';
+$VERSION = '1.12';
 
 1;
 
@@ -28,9 +28,11 @@ J/JS/JSMYSER/WWW-Search-EuroSeek-1.03.tar.gz
 
 WWW::Search::Excite
 
+J/JS/JSMYSER/WWW-Search-Excite-News-2.04.tar.gz
+
 J/JS/JSMYSER/WWW-Search-GoTo-1.07.tar.gz
 
-J/JS/JSMYSER/WWW-Search-Google-2.20.tar.gz
+J/JS/JSMYSER/WWW-Search-Google-2.21.tar.gz
 
 WWW::Search::HotBot
 
@@ -42,6 +44,8 @@ M/MT/MTHURN/WWW-Search-Magellan-2.06.tar.gz
 
 J/JS/JSMYSER/WWW-Search-MetaCrawler-2.07.tar.gz
 
+J/JS/JSMYSER/WWW-Search-News-2.05.tar.gz
+
 J/JS/JSMYSER/WWW-Search-NorthernLight.-2.06.tar.gz
 
 J/JS/JSMYSER/WWW-Search-OpenDirectory-2.02.tar.gz
@@ -56,7 +60,9 @@ WWW::Search::Translator
 
 J/JS/JSMYSER/WWW-Search-X-Search-1.06.tar.gz
 
-M/MT/MTHURN/WWW-Search-Yahoo-2.13.tar.gz
+M/MT/MTHURN/WWW-Search-Yahoo-2.14.tar.gz
+
+WWW::Search::YahooNews
 
 J/JS/JSMYSER/WWW-Search-ZDNet-2.02+.tar.gz
 
